pub enum ComplexNumber {
Single((Box<Value>, Box<Value>)),
Array(Vec<(Box<Value>, Box<Value>)>),
}Expand description
Both the real and imaginary parts of a complex number must be of the same type, and obviously must be numbers.
Variants